#
# spec file for package targetcli
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           targetcli
Summary:        Generic SCSI target CLI shell
License:        Apache-2.0
Group:          Applications/System
Version:        2.1
Release:        5.3
%define oname targetcli
Url:            http://www.github.com/Datera/targetcli
Source:         %{oname}-%{version}.tar.bz2
Source1:        %{oname}-systemd.service
Source2:        load_targetcli_config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       lio-utils
Requires:       python
Requires:       python-configobj
Requires:       python-configshell
Requires:       python-prettytable
Requires:       python-rtslib-rbd
# explicit Provides advertising RBD support
Provides:       %{name}-rbd = %{version}
Obsoletes:      %{name}-rbd < %{version}
BuildRequires:  epydoc
BuildRequires:  python-configobj
BuildRequires:  python-configshell
BuildRequires:  python-devel
BuildRequires:  python-prettytable
BuildRequires:  python-rtslib-rbd
%if 0%{?suse_version} >= 1230
BuildRequires:  systemd
%endif
%{?systemd_requires}
Patch1:         %{oname}-git-update.patch
Patch2:         %{oname}-fix-git-version-for-suse.patch
Patch3:         %{oname}-update-man-page-examples.patch
Patch4:         %{oname}-allow-nonexistent-portal-ips.patch
Patch5:         %{oname}-fb-rbd.patch
Patch6:         %{oname}-fix-exit.patch
Patch7:         %{oname}-refactor-fileio-backstore-creation.patch

%description
targetcli is an administration tool for managing storage targets
using the kernel LIO core target and compatible target fabric modules.
The targetcli CLI is built on top of the python configshell CLI framework.

%prep
%setup -q -n %{oname}-%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6	-p1
%patch7	-p1

%build
%{__python} setup.py build

%install
%{__python} setup.py install --skip-build --root=%{buildroot} --prefix=%{_prefix}
mkdir -p %{buildroot}%{_mandir}/man8
mv doc/targetcli.8 %{buildroot}%{_mandir}/man8/targetcli.8
gzip -9 %{buildroot}%{_mandir}/man8/targetcli.8
# install systemd service file
install -D -m 0644 %{S:1} %{buildroot}%{_unitdir}/targetcli.service
# create target config directory
install -d %{buildroot}/etc/target
# install helper script to load config from file
install -D -m 0755 %{S:2} %{buildroot}%{_bindir}

%clean
rm -rf %{buildroot}

%post
%{service_add_post targetcli.service}

%postun
%{service_del_postun targetcli.service}

%pre
%{service_add_pre targetcli.service}

%preun
%{service_del_preun targetcli.service}

%files
%defattr(-,root,root,-)
%{python_sitelib}
%{_bindir}/targetcli
%{_bindir}/targetcli-ng
%{_bindir}/load_targetcli_config
%doc COPYING README.md
%{_mandir}/man8/targetcli.8*
%{_unitdir}/targetcli.service
%dir /etc/target

%changelog
* Fri Dec 18 2015 lszhu@suse.com
- fix BNC#910538,refactor fileio backstore creation, fix bugs like
  silient failure when file size not spicfied.
  Patch:targetcli-refactor-fileio-backstore-creation.patch
  refactored by Lee Duncan
* Wed Dec  2 2015 lszhu@suse.com
- fix BNC#948529 - targetcli - TAB-ing 'exit' confirmation aborts
  it
  patch:targetcli-fix-exit.patch
* Fri Nov 20 2015 lduncan@suse.com
- Update systemd service start to load current configuration,
  if any, using load_targetcli_config (bsc#954234)
* Fri Sep 25 2015 ddiss@suse.com
- Add explicit Provides for "targetcli-rbd", to advertise RBD module
  support. Similarly, use "python-rtslib-rbd" Requires; (bnc#947555).
* Wed Sep 23 2015 ddiss@suse.com
- Hardcode Release tag for SES2 release.
* Thu Aug 13 2015 ddiss@suse.com
- Add support for the Ceph RBD backend; (fate#318836); (fate#319433).
  + targetcli-fb-rbd.patch
* Tue Aug  4 2015 ddiss@suse.com
- Allow portals for nonexistent IP addresses; (bnc#940531).
  + targetcli-allow-nonexistent-portal-ips.patch
* Thu Jul 31 2014 lduncan@suse.com
- Updated spec file to require lio-utils, and
  systemd service file to require lio-utils 'target'
  service (bnc#885565)
* Fri Jun 27 2014 lduncan@suse.com
- Updates for bnc#880355:
  * added patch to update GIT_VERSION string in python lib
    targetcli-fix-git-version-for-suse.patch
  * added service file to work minimally with systemd:
    targetcli-systemd.service
  * updated spec file:
  - removed dependency on lio-utils
  - updated rtslib dependency to include newer version
  - updated to install new service file
  * updated man page examples
  * added systemd helper script, installed in /usr/bin:
    load_targetcli_config
  * added patch to update man page examples:
    targetcli-update-man-page-examples.patch
* Mon May 19 2014 hare@suse.de
- Fixup spec file
* Thu May 15 2014 hare@suse.de
- Update to official version 2.1
  * Add targetcli-2.1.tar.bz2
  * Remove targetcli-fb-2.0.fb18.tar.gz
  * Remove fix-debian-copyright-license.patch
- Include fixes from git tree, commit b18e22a611
  * Add targetcli-git-update.patch
* Wed Mar  6 2013 vuntz@suse.com
- Update to fb branch, using 2.0.fb18 tarball, matching the update
  of python-rtslib to fb branch.
- Remove now unneeded BuildRequires/Requires on python-configobj,
  python-ipaddr and python-netifaces, and add instead
  python-ethtool.
* Mon Jan 21 2013 hare@suse.de
- Build package for SLES11 SP3 (FATE#313787)
* Fri Jan 18 2013 hare@suse.de
- Fixup debian/copyright to refer to correct license (bnc#799213)
* Mon Oct  1 2012 hare@suse.de
- Initial package, version 2.0rc2
- Include patches from git tree, commit id e872b64
